Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(263)

Unified Diff: content/common/gpu/media/gpu_video_decode_accelerator.cc

Issue 324143002: Decouple IPC::MessageFilter from IPC::Channel (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Landing Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/gpu/gpu_channel.cc ('k') | content/plugin/plugin_channel.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/gpu/media/gpu_video_decode_accelerator.cc
diff --git a/content/common/gpu/media/gpu_video_decode_accelerator.cc b/content/common/gpu/media/gpu_video_decode_accelerator.cc
index 4ac70731d39ecbe95d6e8c90b45ab4942ab97fca..0d315dae4e88cd427753086637e79888ba9f4c8f 100644
--- a/content/common/gpu/media/gpu_video_decode_accelerator.cc
+++ b/content/common/gpu/media/gpu_video_decode_accelerator.cc
@@ -76,12 +76,12 @@ class GpuVideoDecodeAccelerator::MessageFilter : public IPC::MessageFilter {
MessageFilter(GpuVideoDecodeAccelerator* owner, int32 host_route_id)
: owner_(owner), host_route_id_(host_route_id) {}
- virtual void OnChannelError() OVERRIDE { channel_ = NULL; }
+ virtual void OnChannelError() OVERRIDE { sender_ = NULL; }
- virtual void OnChannelClosing() OVERRIDE { channel_ = NULL; }
+ virtual void OnChannelClosing() OVERRIDE { sender_ = NULL; }
- virtual void OnFilterAdded(IPC::Channel* channel) OVERRIDE {
- channel_ = channel;
+ virtual void OnFilterAdded(IPC::Sender* sender) OVERRIDE {
+ sender_ = sender;
}
virtual void OnFilterRemoved() OVERRIDE {
@@ -103,11 +103,11 @@ class GpuVideoDecodeAccelerator::MessageFilter : public IPC::MessageFilter {
bool SendOnIOThread(IPC::Message* message) {
DCHECK(!message->is_sync());
- if (!channel_) {
+ if (!sender_) {
delete message;
return false;
}
- return channel_->Send(message);
+ return sender_->Send(message);
}
protected:
@@ -116,8 +116,8 @@ class GpuVideoDecodeAccelerator::MessageFilter : public IPC::MessageFilter {
private:
GpuVideoDecodeAccelerator* owner_;
int32 host_route_id_;
- // The channel to which this filter was added.
- IPC::Channel* channel_;
+ // The sender to which this filter was added.
+ IPC::Sender* sender_;
};
GpuVideoDecodeAccelerator::GpuVideoDecodeAccelerator(
« no previous file with comments | « content/common/gpu/gpu_channel.cc ('k') | content/plugin/plugin_channel.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698